Saruman: a logic, configuration based, distribuable firewall
############################################################

Saruman: a logic, configuration based, distribuable firewall.

Saruman is a extended firewall (meaning firewall + dns + dhcp +intruision detection + reverse proxy)
build by a former `Iresam <https://www.iresam.org>`_.
It targets I-Resam need's first but should be enough flexible to be used elsewhere.

*saruman* takes care of the boring bits for you.

Here's an overview of the documentation we have for you. First the
documentation on *using* saruman:

.. toctree::
   :maxdepth: 2

   overview
   options
   assumptions
   further_reading

And documentation on *saruman* as a project; for instance for reporting
bugs and fixing the code:

.. toctree::
   :maxdepth: 1

   project
   developing
   entrypoints
   changelog